@@ -55,6 +55,11 @@
 #include <giomm/dbusmessage.h>
 #include <giomm/dbusmethodinvocation.h>
 #include <giomm/dbusobject.h>
+#include <giomm/dbusobjectmanager.h>
+#include <giomm/dbusobjectmanagerclient.h>
+#include <giomm/dbusobjectmanagerserver.h>
+#include <giomm/dbusobjectproxy.h>
+#include <giomm/dbusobjectskeleton.h>
 #include <giomm/dbusownname.h>
 #include <giomm/dbusproxy.h>
 #include <giomm/dbusserver.h>
@@ -72,6 +77,9 @@
 #include <giomm/file.h>
 #include <giomm/fileattributeinfo.h>
 #include <giomm/fileattributeinfolist.h>
+#ifndef G_OS_WIN32
+#include <giomm/filedescriptorbased.h>
+#endif
 #include <giomm/fileenumerator.h>
 #include <giomm/fileicon.h>
 #include <giomm/fileinfo.h>
@@ -109,6 +117,7 @@
 #include <giomm/permission.h>
 #include <giomm/pollableinputstream.h>
 #include <giomm/pollableoutputstream.h>
+#include <giomm/propertyaction.h>
 #include <giomm/proxy.h>
 #include <giomm/proxyaddress.h>
 #include <giomm/proxyresolver.h>
@@ -141,11 +150,13 @@
 #include <giomm/threadedsocketservice.h>
 #include <giomm/tlscertificate.h>
 #include <giomm/tlsclientconnection.h>
+#include <giomm/tlsclientconnectionimpl.h>
 #include <giomm/tlsconnection.h>
 #include <giomm/tlsdatabase.h>
 #include <giomm/tlsinteraction.h>
 #include <giomm/tlspassword.h>
 #include <giomm/tlsserverconnection.h>
+#include <giomm/tlsserverconnectionimpl.h>
 #ifndef G_OS_WIN32
 #include <giomm/unixconnection.h>
 #include <giomm/unixcredentialsmessage.h>
